﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Net;
using System.IO;
using System.Windows.Forms;

namespace WebMinerDemo
{
    static class MiningHelpers
    {
        /// <summary>
        /// Downloads an image from a link to memory. The download is non-asyncronous
        /// and returns null if unsucessful
        /// </summary>
        public static Image DownloadImage(string link)
        {
            WebClient webClient = new WebClient();
            Stream stream = null;

            try
            {
                stream = webClient.OpenRead(link);
                return Image.FromStream(stream);
            }
            catch
            {
                MessageBox.Show(link, Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error);
                return null;
            }
            finally
            {
                if (webClient!= null)
                  webClient.Dispose();

                if (stream != null)
                    stream.Dispose();
            }
        }

        public static bool HasRobotRules(string siteRoot)
        {
            try
            {
                siteRoot = siteRoot.TrimEnd('/');
                string filePath = siteRoot + "/robots.txt";
                WebRequest request = HttpWebRequest.Create(filePath);
                request.Method = "HEAD"; // Just get the document headers, not the data.
                request.Credentials = System.Net.CredentialCache.DefaultCredentials;
                // This may throw a WebException:
                using (HttpWebResponse response = (HttpWebResponse)request.GetResponse())
                {
                    return (response.StatusCode == HttpStatusCode.OK);
                }
            }
            catch
            {
                return false;
            }
        }
    }
}
